{ mailserver, config, lib, pkgs, ... }: 
{
  imports = [
    ./nginx
    mailserver.nixosModule
  ];

  mailserver = rec {
    enable = config.system.mailserver.enable;
    domains = [
      "${config.domains.p2}"
      "${config.domains.blox}"
      "${config.domains.luna}"
      "${config.domains.corn}"
    ];
    fqdn = "mx.${config.domains.p2}";
    certificateScheme = "acme-nginx";
    localDnsResolver = false;
    redis.port = 1515;

    # Passwords made with 'mkpasswd -sm bcrypt'
    loginAccounts = {
      "noreply@${config.domains.p2}" = {
        hashedPasswordFile = pkgs.writeText "noreply" config.secrets.noreplyMailHash;
        sendOnly = true;
      };    
      "jimbo@${config.domains.p2}" = {
        hashedPasswordFile = pkgs.writeText "jimbo" config.secrets.jimboMailHash;
        aliases = [
          "james@${config.domains.p2}"
          "jimbo@${config.domains.blox}"

          "vice@${config.domains.p2}"
          "vice@${config.domains.blox}"
          "yara@${config.domains.p2}"

          "contact@${config.domains.p2}"
        ];
      };
      "luna@${config.domains.luna}" = {
        hashedPasswordFile = pkgs.writeText "luna" config.secrets.lunaMailHash;
        aliases = [
          "luna@${config.domains.blox}"
          "contact@${config.domains.blox}"
          "ibu@${config.domains.blox}"
        ];
      };
      "contact@${config.domains.corn}" = {
        hashedPasswordFile = pkgs.writeText "corn" config.secrets.cornMailHash;
        aliases = [ "freecorn@${config.domains.blox}" ];
      };
    };
  };

  # Rspamd port from earlier to avoid overlap
  services.redis.servers.rspamd.port = 1515;
}
